sftplib - A **very** simple S/FTP client python package
=======================================================

Shamelessly copied (with minor modifications) from [qftplib](https://github.com/lfbos/qftplib)
